module ComplexValidation
  extend ActiveSupport::Concern
  included do
    # nested_to_array
    resource_class.send(:define_method, :nested_to_array) do |attributes, key|
      vals = attributes.fetch(key, [])
      vals = [vals] unless vals.kind_of? Array
      vals
    end

    # get_val_blank
    resource_class.send(:define_method, :get_val_blank) do |attributes, key|
      vals = nested_to_array(attributes, key)
      vals.all?(&:blank?)
    end

    # person_blank
    #   Requires first name or last name or name
    resource_class.send(:define_method, :person_blank) do |attributes|
      return true if attributes.blank?
      first_name_blank = get_val_blank(attributes, :first_name)
      last_name_blank = get_val_blank(attributes, :last_name)
      name_blank = get_val_blank(attributes, :name)
      first_name_blank && last_name_blank && name_blank
    end

    # date_blank
    #   Requires date
    resource_class.send(:define_method, :date_blank) do |attributes|
      return true if attributes.blank?
      get_val_blank(attributes, :date)
    end

    # identifier_blank
    #   Requires identifier
    resource_class.send(:define_method, :identifier_blank) do |attributes|
      return true if attributes.blank?
      get_val_blank(attributes, :identifier)
    end

    # funding reference blank
    # Require one of the fields to be filled in
    resource_class.send(:define_method, :fundref_blank) do |attributes|
      return true if attributes.blank?
      id_blank = get_val_blank(attributes, :funder_identifier)
      name_blank = get_val_blank(attributes, :funder_name)
      award_number_blank = get_val_blank(attributes, :award_number)
      award_uri_blank = get_val_blank(attributes, :award_uri)
      award_title_blank = get_val_blank(attributes, :award_title)
      id_blank && name_blank && award_number_blank && award_uri_blank && award_title_blank
    end

    # subject blank
    # Require all of the fields to be filled in
    resource_class.send(:define_method, :subject_blank) do |attributes|
      return true if attributes.blank?
      id_blank = get_val_blank(attributes, :subject_identifier)
      species_blank = get_val_blank(attributes, :subject_species)
      type_blank = get_val_blank(attributes, :subject_type)
      sex_blank = get_val_blank(attributes, :subject_sex)
      age_blank = get_val_blank(attributes, :subject_age)
      id_blank && species_blank && type_blank && sex_blank && age_blank
    end

    # relation_blank
    #   Requires title / url / identifier and relationship
    resource_class.send(:define_method, :relation_blank) do |attributes|
      return true if attributes.blank?
      identifiers_blank = get_id_blank(attributes, :complex_identifier_attributes)
      title_blank = get_val_blank(attributes, :title)
      url_blank = get_val_blank(attributes, :url)
      rel_blank = get_val_blank(attributes, :relationship)
      (title_blank && url_blank && identifiers_blank) || rel_blank
    end

    # get_id_blank
    resource_class.send(:define_method, :get_id_blank) do |attributes, key|
      identifiers_blank = true
      identifiers = nested_to_array(attributes, key)
      identifiers.each do |id|
        ids = nested_to_array(id, :identifier)
        identifiers_blank = identifiers_blank && ids.all?(&:blank?)
      end
      identifiers_blank
    end

  end
end