# Generated via
#  `rails generate hyrax:work CrcDataset`
class CrcDataset < ActiveFedora::Base
  include ::Hyrax::WorkBehavior

  self.indexer = CrcDatasetIndexer
  # Change this to restrict which works can be added as a child.
  # self.valid_child_concerns = []
  validates :title, presence: { message: 'Your CRC dataset must have a title.' }

  # ------ properties from core metadata ------
  # property date_modified          - not displayed (filled in by the system)
  # property date_uploaded          - not displayed (filled in by the system)
  # property depositor              - not displayed (filled in by the system)
  # property title                  - keep

  # ------ properties from basic metadata ------
  # property alternative_title      - keep
  # property label                  - not displayed, used for file version label
  # property relative_path          - not displayed, used for file storage
  # property import_url             - not displayed, used for file imports
  # property resource_type          - keep
  # property creator                - do not display
  # property contributor            - do not display
  # property description            - keep
  # property abstract               - keep
  # property keyword                - keep
  # property license                - keep
  # property rights_notes           - do not display
  # property rights_statement       - do not display
  # property access_right           - do not display
  # property publisher              - keep
  # property date_created           - do not display
  # property subject                - keep
  # property language               - keep
  # property identifier             - do not display (used to store alternate identifiers)
  # property based_near             - do not display
  # property related_url            - do not display
  # property bibliographic_citation - not displayed (generated by the system)
  # property source                 - do not display (should be filled in by the system for bulk imports)

  # ------ properties from Datacite metadata ------
  property :doi, predicate: ::RDF::Vocab::DataCite.doi, multiple: false do |index|
    index.as :symbol
  end

  property :complex_person, predicate: ::RDF::Vocab::SIOC.has_creator, class_name:"ComplexPerson"

  # property :date_published, predicate: ::RDF::Vocab::Rdms.datePublished, multiple: false do |index|
  #   index.type :date
  #   index.as :stored_sortable
  # end

  property :complex_date, predicate: ::RDF::Vocab::DC.date, class_name:"ComplexDate"

  property :complex_identifier, predicate: ::RDF::Vocab::Rdms.identifier, class_name:"ComplexIdentifier"

  # size and format to be obtained from the files attached

  # label property in basic metadata can be used for version label

  # description and abstract is in the basic metadata. Ignoring other descriptions for now.

  # Geolocation - would this be used? Ignoring for now.

  property :complex_funding_reference, predicate: ::RDF::Vocab::DataCite.fundref, class_name:"ComplexFundingReference"

  property :complex_relation, predicate: ::RDF::Vocab::DC.relation, class_name:"ComplexRelation"


  # ------ properties from CRC metadata ------

  property :parent_work_id, predicate: ::RDF::Vocab::Rdms.parentWorkId, multiple: false do |index|
    index.as :symbol
  end

  property :work_type, predicate: ::RDF::Vocab::Rdms.workType, multiple: false do |index|
    index.as :stored_searchable
  end
  
  property :crc_resource_type, predicate: ::RDF::Vocab::Rdms.crcResourceType, multiple: false do |index|
    index.as :stored_searchable, :facetable
  end

  property :modality, predicate: ::RDF::Vocab::Rdms.modality do |index|
    index.as :stored_searchable, :facetable
  end

  property :complex_subject, predicate: ::RDF::Vocab::Rdms.subject, class_name:"ComplexSubject"

  property :approval_number, predicate: ::RDF::Vocab::Rdms.approvalNumber, multiple: false do |index|
    index.as :symbol
  end

  property :extra_information, predicate: ::RDF::Vocab::Rdms.extraInformation do |index|
    index.as :stored_searchable
  end

  property :software_version, predicate: ::RDF::Vocab::Rdms.softwareVersion do |index|
    index.as :stored_searchable
  end

  # ------ properties from DublinCore metadata ------
  property :coverage, predicate: ::RDF::Vocab::DC.coverage, multiple: false do |index|
    index.as :stored_searchable, :facetable
  end

  # This must be included at the end, because it finalizes the metadata
  # schema (by adding accepts_nested_attributes)
  include ::Hyrax::BasicMetadata
  include ComplexValidation
  accepts_nested_attributes_for :complex_person, reject_if: :person_blank, allow_destroy: true
  accepts_nested_attributes_for :complex_date, reject_if: :date_blank, allow_destroy: true
  accepts_nested_attributes_for :complex_identifier, reject_if: :identifier_blank, allow_destroy: true
  accepts_nested_attributes_for :complex_funding_reference, reject_if: :fundref_blank, allow_destroy: true
  accepts_nested_attributes_for :complex_relation, reject_if: :relation_blank, allow_destroy: true
  accepts_nested_attributes_for :complex_subject, reject_if: :all_blank, allow_destroy: true
end
