# frozen_string_literal: true
class SolrDocument
  include Blacklight::Solr::Document
  include Blacklight::Gallery::OpenseadragonSolrDocument

  # Adds Hyrax behaviors to the SolrDocument.
  include Hyrax::SolrDocumentBehavior


  # self.unique_key = 'id'

  # Email uses the semantic field mappings below to generate the body of an email.
  SolrDocument.use_extension(Blacklight::Document::Email)

  # SMS uses the semantic field mappings below to generate the body of an SMS email.
  SolrDocument.use_extension(Blacklight::Document::Sms)

  # DublinCore uses the semantic field mappings below to assemble an OAI-compliant Dublin Core document
  # Semantic mappings of solr stored fields. Fields may be multi or
  # single valued. See Blacklight::Document::SemanticFields#field_semantics
  # and Blacklight::Document::SemanticFields#to_semantic_values
  # Recommendation: Use field names from Dublin Core
  use_extension(Blacklight::Document::DublinCore)

  # Do content negotiation for AF models. 

  use_extension( Hydra::ContentNegotiation )

  def complex_date
    self[Solrizer.solr_name('complex_date', :displayable)]
  end

  def complex_identifier
    self[Solrizer.solr_name('complex_identifier', :displayable)]
  end

  def complex_person
    self[Solrizer.solr_name('complex_person', :displayable)]
  end

  def doi
    self[Solrizer.solr_name('doi', :symbol)]
  end

  def parent_work_id
    self[Solrizer.solr_name('parent_work_id', :symbol)]
  end

  def work_type
    self[Solrizer.solr_name('work_type', :stored_searchable)]
  end

  def complex_relation
    self[Solrizer.solr_name('complex_relation', :displayable)]
  end
  
  def complex_funding_reference
    self[Solrizer.solr_name('complex_funding_reference', :displayable)]
  end

  def modality
    self[Solrizer.solr_name('modality', :stored_searchable)]
  end

  def complex_subject
    self[Solrizer.solr_name('complex_subject', :displayable)]
  end

  def approval_number
    self[Solrizer.solr_name('approval_number', :symbol)]
  end

  def extra_information
    self[Solrizer.solr_name('extra_information', :stored_searchable)]
  end

  def software_version
    self[Solrizer.solr_name('software_version', :stored_searchable)]
  end
end
